#[repr(C)]pub struct libinput_config_area_rectangle {
pub x1: f64,
pub y1: f64,
pub x2: f64,
pub y2: f64,
}Expand description
@ingroup config
Describes a rectangle to configure a device’s area, see libinput_device_config_area_set_rectangle().
This struct describes a rectangle via the upper left points (x1, y1) and the lower right point (x2, y2).
All arguments are normalized to the range [0.0, 1.0] to represent the corresponding proportion of the device’s width and height, respectively. A rectangle covering the whole device thus comprises of the points (0.0, 0.0) and (1.0, 1.0).
The conditions x1 < x2 and y1 < y2 must be true.
Fields
x1: f64y1: f64x2: f64y2: f64Trait Implementations
Sourceimpl Clone for libinput_config_area_rectangle
impl Clone for libinput_config_area_rectangle
Sourcefn clone(&self) -> libinput_config_area_rectangle
fn clone(&self) -> libinput_config_area_rectangle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for libinput_config_area_rectangle